MemoryService class

Mixed-in types
  • VMServiceWrapper

Constructors

MemoryService()

Properties

allClasses ↔ List<ClassHeapStats>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infoList ↔ List<ClassHeapStats>
getter/setter pair
memoryUseage ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceWrapper → ServiceWrapper
finalinherited
vmInfo ↔ String
getter/setter pair

Methods

byteToString(int size) → String
getClassDetailInfo(String classId, dynamic completion(ClsModel?)) → void
getInfos(Function completion) → void
getInstanceIds(String classId, int limit, dynamic completion(List<String?>)) → void
hidePrivateClasses(bool hide) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sort<T>(Comparable<T>? getField(ClassHeapStats d), bool descending, void completion()) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited