Property class

Constructors

Property(bool? isConst, bool? isStatic, bool? isFinal, String? type, String? name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConst → bool?
final
isFinal → bool?
final
isStatic → bool?
final
name → String?
final
propertyStr → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited